close all
clear all
datdir = 'C:\MyFiles\Teach\Networks\Data\';
dattxt = 'USAreturns';
tmax = 10;
M = 100;
toplot = 1;

%% Load the time series
xV = load([datdir,dattxt,'.dat']);
% eval(['yM=load(''',datdir,dattxt,'.dat'');'])
n = length(xV);
%% Mutual information, first for the original time series
mutranM = NaN*ones(tmax+1,M+1); % Computes I(0) as well
mutM = mutual(xV,tmax);
mutranM(:,1) = mutM(:,2);
%% Mutual information on the randomized time series
for im=1:M
    yV = xV(randperm(n)); % Random suffling of the time series
    mutM = mutual(yV,tmax);
    mutranM(:,im+1) = mutM(:,2);
end
%% Plot the results of the randomized test
if toplot
    figure(1)
    clf
    plot([0:tmax]',mutranM(:,1),'k','linewidth',1.5)
    hold on
    plot([0:tmax]',mutranM(:,2:M+1),'c')
    plot([0:tmax]',mutranM(:,1),'k','linewidth',1.5)
    xlabel('\tau')
    ylabel('I(\tau)')
    legend('original','resampled','Location','Best')
    title(sprintf('%s I(tau) original and %d resampled',dattxt,M))
end
%% Make the rank test for each delay of mutual information
IrnkV = NaN*ones(tmax+1,1);
IpvalV = NaN*ones(tmax+1,1);
fprintf(' tau    I(tau)    rank order   resampled p-value \n');
for tau=1:tmax+1
    [omutV, imutV]=sort(mutranM(tau,:)); % Sort the M+1 I(tau) values
    IrnkV(tau) = find(imutV == 1); % and find the rank of the original
    IpvalV(tau) = 1-(IrnkV(tau)-0.326)/(M+1+0.348); 
    fprintf(' %d \t %3.3f \t %d \t %1.3f \n',tau-1,mutranM(tau,1),...
            IrnkV(tau),IpvalV(tau));
end   
