function xM = SysGourevitch06m7(n)
% xM = SysGourevitch06m7(n)
% SysGourevitch06m7 generates a multivariate linear and nonlinear time
% series of 3 variables. In parenthesis the largest lag of the
% driving variable in the expression for the response variable.
% x1(1)-->x2    x1(1)-->x3   x2(1)-->x3
% INPUTS
% - n   : the time series length
% OUTPUTS
% - xM  : the n x 3 matrix of the generated time series
% Reference 
% Biol Cybern 2006
% Linear and nonlinear casuality between signals: methods, examples and
% neurophysiological applications
% Gourvitch, Bouquin-Jeannes, Faucon
% Example Model 7: nonlinear trivariate model

ntrans = 100;
wM = randn(n+ntrans,3);
xM = NaN*ones(n+ntrans,3);
xM(1,:) = wM(1,:);
for t=2:n+ntrans
   xM(t,1)=3.4*xM(t-1,1)*(1-xM(t-1,1)^2)*exp(-xM(t-1,1)^2)+0.4*wM(t,1);
   xM(t,2)=3.4*xM(t-1,2)*(1-xM(t-1,2)^2)*exp(-xM(t-1,2)^2)+0.5*xM(t-1,1)*xM(t-1,2)+0.4*wM(t,2);
   xM(t,3)=3.4*xM(t-1,3)*(1-xM(t-1,3)^2)*exp(-xM(t-1,3)^2)+0.3*xM(t-1,2)+0.5*xM(t-1,1)^2+0.4*wM(t,3);
end;
xM = xM(ntrans+1:n+ntrans,:);
