% Compute and plot cross-correlation of time series generated by VAR 
clear all
pridir = 'C:\MyFiles\Teach\Networks\Figures\';
pritxt = 'ARinterdep';
n = 300;
tmax = 10;
alpha = 0.05; % Significance level
toprint = 1;
% phi0V = [0 0]';
% phi1M = [0.95 0; 0 0.85];
K = 2;
p = 1;
pfit = 5;
A = zeros(K,K,p+1);
A(:,:,1) =eye(2);
% A(:,:,2) =[-0.95 0; 0 -0.85];
% A(:,:,2) =[-0.95 0; -0.5 -0.85];
A(:,:,2) =[-1.2 0.5; -0.6 -0.3];

% A(:,:,2) = [-1.5 0.1;-0.2 1.5];
% A(:,:,3) = [0.7 -0.3;0.1 0.7];
autax = [-0.3 1];
%croax = [-0.3 0.3];
croax = [-0.3 1];

zalpha = norminv(1-alpha/2);
tauV = [-tmax:tmax]';
%% Generate the K time series 
randn('state',0);
% yM = NaN*ones(n,K);
% for k=1:K
%     yM(:,k) = ARm(phi1V,n);
% yM(:,2) = ARm(phi2V,n);

modS = idarx(A,[],1);
eM = iddata([],randn(n,2));
yS = sim(modS,eM);
yM = yS.OutputData;

%% Plot the two original time series
figure(1)
clf
paperfigure;
plot(yM(:,1),'.-k')
hold on
plot(yM(:,2),'.-r')
xlabel('t')
ylabel('x(t)')
legend('X','Y','Location','Best')
title('The time series X and Y')

acy1M = autocor(yM(:,1),1,tmax);
acy2M = autocor(yM(:,2),1,tmax);
figure(2)
clf
paperfigure;
plot(acy1M(2:tmax+1,1),acy1M(2:tmax+1,2),'.-k')
hold on
plot(acy2M(2:tmax+1,1),acy2M(2:tmax+1,2),'.-r')
plot([0 tmax],(zalpha/sqrt(n))*[1 1],'--c')
plot([0 tmax],-(zalpha/sqrt(n))*[1 1],'--c')
axis([0 tmax autax])
xlabel('\tau')
ylabel('r(\tau)')
legend('X','Y','Location','Best')
title('Autocorrelation of the two time series')
%% Cross-correlation of the two original time series
ccyV = crosscorr(yM(:,1),yM(:,2),tmax);
figure(3)
clf
paperfigure;
plot(tauV,ccyV,'.-')
hold on
plot([-tmax tmax],[0 0],'k')
plot([-tmax tmax],(zalpha/sqrt(n))*[1 1],'--c')
plot([-tmax tmax],-(zalpha/sqrt(n))*[1 1],'--c')
axis([-tmax tmax croax])
xlabel('\tau')
ylabel('r_{XY}(\tau)')
title('Cross-correlation of the original time series');

%% Fit AR model to each of the two time series
xM = NaN*ones(n,K);
for k=1:K
    th=ar(yM(:,k),pfit);
    ypreV = predict(th,yM(:,k),1);
    xM(:,k) = yM(:,k) - ypreV{1};
end

%% Plot the two prewhitened time series
figure(4)
clf
paperfigure;
plot(xM(:,1),'.-k')
hold on
plot(xM(:,2),'.-r')
xlabel('t')
ylabel('x(t)')
legend('X','Y','Location','Best')
title('The prewhitened time series X and Y')

acx1M = autocor(xM(:,1),1,tmax);
acx2M = autocor(xM(:,2),1,tmax);
figure(5)
clf
paperfigure;
plot(acx1M(2:tmax+1,1),acx1M(2:tmax+1,2),'.-k')
hold on
plot(acx2M(2:tmax+1,1),acx2M(2:tmax+1,2),'.-r')
plot([0 tmax],(zalpha/sqrt(n))*[1 1],'--c')
plot([0 tmax],-(zalpha/sqrt(n))*[1 1],'--c')
axis([0 tmax autax])
xlabel('\tau')
ylabel('r(\tau)')
legend('X','Y','Location','Best')
title('Autocorrelation of the prewhitened time series')
%% Cross-correlation of the prewhitened time series
ccxV = crosscorr(xM(:,1),xM(:,2),tmax);
figure(6)
clf
paperfigure;
plot(tauV,ccxV,'.-')
hold on
plot([-tmax tmax],[0 0],'k')
plot([-tmax tmax],(zalpha/sqrt(n))*[1 1],'--c')
plot([-tmax tmax],-(zalpha/sqrt(n))*[1 1],'--c')
axis([-tmax tmax croax])
xlabel('\tau')
ylabel('r_{XY}(\tau)')
title('Cross-correlation of the prewhitened time series');

if toprint
    figure(1)
    set(gcf,'PaperPosition',[0 0 15 10])
    eval(['print -djpeg90 ',pridir,pritxt,'oriser.jpg'])
    figure(2)
    set(gcf,'PaperPosition',[0 0 15 10])
    eval(['print -djpeg90 ',pridir,pritxt,'oriaut.jpg'])
    figure(3)
    set(gcf,'PaperPosition',[0 0 15 10])
    eval(['print -djpeg90 ',pridir,pritxt,'oricro.jpg'])
    figure(4)
    set(gcf,'PaperPosition',[0 0 15 10])
    eval(['print -djpeg90 ',pridir,pritxt,'resser.jpg'])
    figure(5)
    set(gcf,'PaperPosition',[0 0 15 10])
    eval(['print -djpeg90 ',pridir,pritxt,'resaut.jpg'])
    figure(6)
    set(gcf,'PaperPosition',[0 0 15 10])
    eval(['print -djpeg90 ',pridir,pritxt,'rescro.jpg'])
end
