% Plot series of world financial indices, parametric test of significance
% of the correlation coefficient, adjacency matrix and input file for pajek 
clear all
datdir = 'C:\MyFiles\Teach\Networks\Data\';
dattxt = 'WorldMarkets';
pridir = 'C:\MyFiles\Teach\Networks\Figures\';
filename = 'C:\MyFiles\Teach\Networks\Data\WorldIndicesCorrCoeff.net';
n = 100;
usereturns = 0;
txtM = str2mat('USA','Australia','UnitedKingdom','Germany','Greece',...
    'Malaysia','SouthAfrica','Croatia');
alpha = 0.01; % Significance level
toplot = 0;
toplothist = 0;
toprint = 0;

symbV = str2mat('''.-k''','''.--k''','''.-.k''','''.:k''','''.-c''',...
    '''.--c''','''.-.c''','''.:c''','''.-r''','''.--r''','''.-.r''','''.:r''');
%% Load the time series and plot them
m = size(txtM,1);
eval(['xM=load(''',datdir,dattxt,'.dat'');'])
xM = xM(end-n:end,:);
if usereturns
    xM(1:n,:)=log(xM(2:n+1,:))-log(xM(1:n,:));
end
% xM = NaN*ones(n+1,m);
% for i=1:m
%     eval(['xM(:,i) =',deblank(txtM(i,:)),'(end-n:end);'])
%     if usereturns
%         xM(1:n,i)=log(xM(2:end,i))-log(xM(1:end-1,i));
%     end
% end
xM = xM(1:n,:)';
figure(1)
clf
paperfigure;
eval(['plot(xM(1,:),',symbV(1,:),')'])
hold on
legtxt = sprintf('''%s'',',deblank(txtM(1,:)));
for i=2:m
    eval(['plot(xM(i,:),',symbV(i,:),')'])
    hold on
    legtxt = sprintf('%s''%s'',',legtxt,deblank(txtM(i,:)));
end
xlabel('day t')
ylabel('x(t)')
eval(['h=legend(',legtxt,'''Location'',''Best'')'])
set(h,'Fontsize',14)
if toprint
    eval(['print -djpeg90 ',pridir,dattxt,'ser.jpg'])
end
%% Plot histograms
if toplothist
    for i=1:m
        figure(i+1)
        clf
        paperfigure;
        histfit(xM(i,:))
        if toprint
            eval(['print -djpeg90 ',pridir,dattxt,'hist',int2str(i),'.jpg'])
        end
    end
end
%% Compute and plot correlation coefficients
count = 0;
rM = NaN*ones(m,m);
stat1M = NaN*ones(m,m); % upper -> corr.coefs, lower-> p-values
stat2M = NaN*ones(m,m); % upper -> corr.coefs, lower-> p-values
adjM = NaN*ones(m,m);
hfigno=gcf;
for i=1:m-1
    for j=i+1:m
        tmpM = corrcoef(xM(i,:),xM(j,:));
        rM(i,j)=tmpM(1,2);
        count = count+1;
        stat1M(i,j) = sqrt(n-2)*rM(i,j)/sqrt(1-rM(i,j).^2);
        stat1M(j,i) = 2*(1-tcdf(abs(stat1M(i,j)),n-2));
        stat2M(i,j) = sqrt(n-3)*0.5*log((1+rM(i,j))/(1-rM(i,j)));
        stat2M(j,i) = 2*(1-normcdf(abs(stat2M(i,j))));
        stat2M(i,j) = rM(i,j);
        if stat2M(j,i)>alpha
            adjM(i,j)=0;
        else
            adjM(i,j)=1;
        end
        if toplot
            figure(hfigno+count)
            clf
            paperfigure;
            plot(xM(i,:),xM(j,:),'.','Markersize',18)
            xlabel(txtM(i,:))
            ylabel(txtM(j,:))
            title(sprintf('n=%d r=%1.3f',n,rM(i,j)))
            if toprint
                eval(['print -djpeg90 ',pridir,dattxt,'rho',int2str(count),'.jpg'])
            end
        end
    end
end
stat1M;
stat2M;
adjM;
if ~isempty(filename)
    InputPajek(txtM,adjM,filename);
end




