% Script 5: CGCI in EEG and networks
alpha = 0.05; % significance level
K = 5; % Number of variables (time series) to use from the set of variables read in.
nonparametric = 1; % Set it to 1 if you want to run a nonparametric test
M = 100; % The number of time-shifted surrogates for the nonparametric 
         % (randomization) test
P = 2; % The order of the VAR model used for the computation of the 
        % conditional Granger causality index (CGCI) 
offsetfrac = 0.1; % For time-shifted surrogates, to shift long enough

xM = load('d:\MyFiles\Teach\Networks\Data\E1.dat');
xM = xM(1:2000,1:end-1); % The last channel is ECG
[n,m]=size(xM);
% rand('state',0)

iV = randperm(m);
% iV = [1:m];
xM = xM(:,iV(1:K));

% Read the names of the channels
[numM,txtC] = xlsread('d:\MyFiles\Teach\Networks\Data\Channel25Names.xls');
nameM = txtC(iV(1:K),:);

% If NaN replace them with interpolated values for each time series
for i=1:K
    i1V = find(isnan(xM(:,i)));
    if ~isempty(i1V)
        iokV = setdiff([1:n]',i1V);
        xM(i1V,i) = interp1(iokV,xM(iokV,i),i1V,'spline');
    end
end

[cgciM,ppcgciM] = CGCinall(xM,P,1);
if nonparametric
    % Randomized CGCI values for the pair (y1,y2)
    npcgciM = NaN*ones(K,K);
    cgcisurT = NaN*ones(M+1,K,K);
    cgcisurT(1,:,:) = cgciM;
    offset = round(n*offsetfrac/2); % time offset for time-shifted surrogates
    istartM = offset+ ceil((n-2*offset)*rand(M,K));
    for i=1:M
        for ik=1:K-1
             for jk=ik+1:K
                % Time-shift for X when X->Y and Y when Y->X
                xsV = xM([istartM(i,ik):n 1:istartM(i,ik)-1],ik);
                ysV = xM([istartM(i,jk):n 1:istartM(i,jk)-1],jk);
                restV = setdiff([1:K],[ik jk]);
                cgcisurT(i+1,ik,jk) = CGCin(xsV,xM(:,jk),xM(:,restV),P,0);
                cgcisurT(i+1,jk,ik) = CGCin(ysV,xM(:,ik),xM(:,restV),P,0);
             end
        end
    end
    for ik=1:K-1
        for jk=ik+1:K
            cgcixyV = squeeze(cgcisurT(:,ik,jk));
            npcgciM(ik,jk) = resampledpvalue(cgcixyV,1);
            cgcixyV = squeeze(cgcisurT(:,jk,ik));
            npcgciM(jk,ik) = resampledpvalue(cgcixyV,1);
        end
    end
end
figno = 1;
tit1txt = sprintf('CGCI_{X->Y}(%d)',P);
h1 = plotnetworktitle(cgciM,[],nameM,tit1txt,figno);
% h1 = plotcolormap(cgciM,nameM,tit1txt,figno,1);
figno = figno + 1;
tit2txt = sprintf('parametric p-value, CGCI_{X->Y}(%d)',P);
tmpM = ppcgciM < alpha;
h2 = plotnetworktitle(tmpM,[],nameM,tit2txt,figno);
% h2 = plotcolormap(ppcgciM,nameM,tit2txt,figno,1);
if nonparametric
    figno = figno + 1;
    tit3txt = sprintf('nonparametric p-value, CGCI_{X->Y}(%d)',P);
    tmpM = npcgciM < alpha;
    h3 = plotnetworktitle(tmpM,[],nameM,tit3txt,figno);
    % h3 = plotcolormap(npcgciM,nameM,tit3txt,figno,1);
end    
figno = figno + 1;
adjppM = adjFDRmatrix(ppcgciM,alpha,2);
tit4txt = sprintf('FDR (a=%1.3f), parametric p-value, CGCI_{X->Y}(%d)',alpha,P);
h4 = plotnetworktitle(adjppM,[],nameM,tit4txt,figno);
% h4 = plotcolormap(adjppM,nameM,tit4txt,figno,1);
figno = figno + 1;
adjnpM = adjFDRmatrix(npcgciM,alpha,2);
tit5txt = sprintf('FDR (a=%1.3f), nonparametric p-value, CGCI_{X->Y}(%d)',alpha,P);
h5 = plotnetworktitle(adjnpM,[],nameM,tit5txt,figno);
% h5 = plotcolormap(adjnpM,nameM,tit5txt,figno,1);

